Crate battler_wamp_values_proc_macro

Crate battler_wamp_values_proc_macro 

Derive Macros

WampDictionary
Procedural macro for deriving battler_wamp_values::WampSerialize and battler_wamp_values::WampDeserialize for a struct that converts to a battler_wamp_values::Dictionary.
WampList
Procedural macro for deriving battler_wamp_values::WampSerialize and battler_wamp_values::WampDeserialize for a struct that converts to a battler_wamp_values::List.